rlubke 01/12/17 19:39:40
Modified: src/tools/org/apache/tomcat/task GTest.java
Log:
Removed setReturnCode( String, String ) and replaced it
with setReturnCodeMsg.
Added additional logic for response body checking.
Revision Changes Path
1.5 +10 -4 jakarta-watchdog-4.0/src/tools/org/apache/tomcat/task/GTest.java
Index: GTest.java
===================================================================
RCS file:
/home/cvs/jakarta-watchdog-4.0/src/tools/org/apache/tomcat/task/GTest.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- GTest.java 2001/12/18 02:31:01 1.4
+++ GTest.java 2001/12/18 03:39:40 1.5
@@ -364,15 +364,14 @@
}
/**
* Describe <code>setReturnCode</code> Sets the expected
* return code and message to be found in the server's
* response.
*
* @param code a valid HTTP resonse status code
* @param message a <code>String</code> value
*/
- public void setReturnCode( String code, String message ) {
- this.returnCode = code;
+ public void setReturnCodeMsg( String message ) {
this.returnCodeMsg = message;
}
@@ -683,6 +682,13 @@
System.out.println( responseBodyString );
}
}
+
+ if ( !expectResponseBody && responseBody != null ) {
+ if ( debug > 0 ) {
+ System.out.println( "Received a response body from the server where
none was expected" );
+ }
+ return false;
+ }
// compare the body
if ( goldenFile == null )
@@ -364,15 +364,14 @@
}
/**
- * Describe <code>setReturnCode</code> Sets the expected
- * return code and message to be found in the server's
+ * Describe <code>setReturnCodeMsg</code> Sets the expected
+ * return message to be found in the server's
* response.
*
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>